Module config

Module config 

PostgreSQL connection configuration.

Mirrors the shape of SshConfig / SftpConfig so the macOS bridge can map a ConnectionProfile onto a PgConfig with the same conventions used for every other protocol.

Structs

PgConfig
SshTunnelRef
Reference to an existing ConnectionManager-managed SSH connection that should be used as a direct-tcpip tunnel for this Postgres connection.

Enums

PgAuthMethod
How to authenticate to the Postgres server.
PgTlsMode
TLS posture for the connection.