Skip to main content Module host_keys Copy item path Source HostKeyMismatch Details surfaced to the user when Verdict::Mismatch caused a rejection. HostKeyStore Persistent store of trusted SSH host keys (analogous to ~/.ssh/known_hosts). HostKeyStoreAccessError Details surfaced to the user when host-key verification could not complete
because the trust store was unavailable. HostKeyVerificationFailure Any verification failure that should be surfaced verbosely to the caller. Verdict Result of verifying a server-offered host key against the local store. VerificationFailureSlot Slot that a Client instance writes a host-key verification failure into
during the SSH handshake. The caller of connect reads it after the error
to build a descriptive user-facing message.